*! version 1.1.1  02mar2005  by Robert Jaeckle jaeckle@ifo.de
*! version 1.1.6  17jan2006  by Marc Muendler  muendler@ucsd.edu

local tlogyr = substr("${tlogyear}",3,2)
local selyr = substr("${selyear}",3,2)
if "$dpref"==""  global dpref = "$dp"

capture mkdir "tex/desc"
capture mkdir "tex/desc/wagediffs"

clear
set memory 500m
set matsize 400
set more off

cd "$rootslct"

tempfile wdi cntrgrpbem concnace oww`selyr' oww99 oww`tlogyr' homoww`selyr' homoww99 homoww`tlogyr' homsecwag swe98 homswe98 cntrgrp_med_wage_`tlogyr' cntrgrp_med_wage_`selyr'

* Country group resetting
capture program drop countrygrp_bem
program define countrygrp_bem
  * Apply BEM cntrybemgrp definitions
  /*-----------------------
   WEU: EMU (3), OWE (6);
   OIN: OIN (5);
   CEE: CEE (2); 
   DEV: APC (1), ODV (4) and RCA (7)
   --------------------------------------------*/
  tab cntrygrp_bem
  gen str3 cntrybemgrp = "CEE" if cntrygrp_bem=="CEE"
  replace  cntrybemgrp = "DEV" if cntrygrp_bem=="APC" | cntrygrp_bem=="ODV" | cntrygrp_bem=="OTR" | cntrygrp_bem=="RCA"
  replace  cntrybemgrp = "OIN" if cntrygrp_bem=="OIN"
  replace  cntrybemgrp = "WEU" if cntrygrp_bem=="EMU" | cntrygrp_bem=="OWE"
  label var cntrybemgrp "Country group BEM"
  rename cntrybemgrp _cntrybemgrp
  encode _cntrybemgrp, gen(cntrybemgrp) label(cntrybem)
  drop _cntrybemgrp
end


/* External data preperation  */
/*----------------------------*/

use "$root/countries/extdata-deflated", clear
keep if year==1999
keep country population
sort country
save `wdi'

use "$root/conc/cntry2bemgrp", clear
rename bubakey country
sort country
compress
save `cntrgrpbem'

use "$root/conc/sector-conc-nace", clear
sort nace11_code
compress
save `concnace'

global oww`selyr' "`oww`selyr''"
global oww99 "`oww99'"
global oww`tlogyr' "`oww`tlogyr''"
global swe98 "`swe98'"
global homoww`selyr' "`homoww`selyr''"
global homoww99 "`homoww99'"
global homoww`tlogyr' "`homoww`tlogyr''"
global homswe98 "`homswe98'"
global homsecwag "`homsecwag'"
do $dpref/#translog-owwwages.do


/*------------------------------*/
/* Construct wage differentials */
/*------------------------------*/

* Regional mean of median wages in year of translog estimation (2000)
*--------------------------------------------------------------------
use `oww`tlogyr'', clear
drop lag_wage_oww_30 lag_wage_oww_40 lag_wage_oww_50 lag_wage_oww_61 lag_wage_oww_62
drop if lag_cntr_wage==.
sort country 
merge country using `wdi', nokeep
tab _merge
list country population lag_cntr_wage if _merge==1 /* _merge==1 is Germany */
drop if country==0
drop _merge
sort country 
merge country using `cntrgrpbem' 
tab _merge
keep if _merge==3
drop _merge
countrygrp_bem
collapse (mean) lag_cntr_wage [pw=population], by(cntrybemgrp) fast
rename lag_cntr_wage lag_cntrgrp_wage
label var lag_cntrgrp_wage "Regional mean wage ${tlogyear}"
gen int year = ${tlogyear}
sort year
merge year using `homoww`tlogyr'', nokeep
drop lag_wage_oww_30_par lag_wage_oww_40_par lag_wage_oww_50_par lag_wage_oww_61_par lag_wage_oww_62_par year _m
rename lag_cntr_wage_par lag_home_wage_par
sort cntrybemgrp
save `cntrgrp_med_wage_`tlogyr''

* Regional mean of median wages in year of selection estimation (1996)
*---------------------------------------------------------------------
use `oww`selyr'', clear
drop wage_oww_30 wage_oww_40 wage_oww_50 wage_oww_61 wage_oww_62
drop if cntr_wage==.
sort country 
merge country using `wdi', nokeep
tab _merge
list country population cntr_wage if _merge==1 /* _merge==1 is Germany */
drop if country==0
drop _merge
sort country 
merge country using `cntrgrpbem' 
tab _merge
keep if _merge==3
drop _merge
countrygrp_bem
collapse (mean) cntr_wage [pw=population], by(cntrybemgrp) fast
rename cntr_wage cntrgrp_wage
label var cntrgrp_wage "Regional mean wage ${selyear}"
gen int year = ${selyear}
sort year
merge year using `homoww`selyr'', nokeep
drop wage_oww_30_par wage_oww_40_par wage_oww_50_par wage_oww_61_par wage_oww_62_par year _m
rename cntr_wage_par home_wage_par
sort cntrybemgrp
save `cntrgrp_med_wage_`selyr''


* Wage differential in year of translog estimation (2000)
*--------------------------------------------------------
use "$root/wages/destatis-gearn-defl", clear
keep if year==${tlogyear}
drop agearn year
rename nace11 nace1
* replace missing with mean aggregate sector wage
gen byte _aggsec = int(nace1/10)
egen _agearn = mean(agearn), by(_aggsec)
replace agearn = _agearn if agearn==.
drop _*
* merge in countries
qui count
local obs = `r(N)'
expand 4
sort nace1
gen cntrybemgrp = _n - int(_n/4-.1)*4
sort cntrybemgrp
merge cntrybemgrp using `cntrgrp_med_wage_`tlogyr''
tab _merge
drop _merge
* wagediffs and German ln wages
gen wagediff=lag_cntrgrp_wage/agearn_med
gen owwdiff =lag_cntrgrp_wage/lag_home_wage_par
label var wagediff "cntrgrp_wage/agearn_med"
label var owwdiff  "cntrgrp_wage/lag_home_w"
gen ln_wagediff=ln(wagediff)
gen ln_owwdiff=ln(wagediff)
label var ln_wagediff "ln(cntrgrp_wage/agearn_med)"
label var ln_owwdiff "ln(cntrgrp_wage/lag_home_w)"
local i 0
foreach var in wagediff ln_wagediff owwdiff ln_owwdiff {
  local i = `i' + 1
  local lbl`i' : variable label `var'
  }
replace agearn_med = ln(agearn_med)
rename agearn_med w_HOM
label var w_HOM "ln Sectoral median wage"
keep nace1 cntrybemgrp wagediff ln_wagediff owwdiff ln_owwdiff w_HOM
preserve
  gen year=${tlogyear}
  sort year cntrybemgrp nace1
  save ${bef_reshape_${tlogyear}}
restore
reshape wide wagediff ln_wagediff owwdiff ln_owwdiff, i(nace1 w_HOM) j(cntrybemgrp)
local x=0
foreach name in $regagg {
  local x=`x'+1
  local i 0
  foreach var in wagediff ln_wagediff owwdiff ln_owwdiff {
    local i = `i' + 1
    rename `var'`x' `var'_`name' 
    label var `var'_`name' "`lbl`i'' `name'"
    }
  }
sort nace1
save ${wage_diff_${tlogyear}}
* aggregate reporting with table
rename nace1 nace11_code
sort nace11_code
merge nace11_code using "$root/conc/nace2bem", nokeep
collapse (mean) wagediff* owwdiff*, by(sec_bem) fast
keep sec_bem wagediff* owwdiff*
preserve 
  tempfile appndtlg
  keep sec_bem owwdiff*
  keep in 1
  foreach reg in $regagg {
    rename owwdiff_`reg' wagediff_`reg'
    }
  replace sec_bem = 0
  save `appndtlg'
restore
keep sec_bem wagediff*
append using `appndtlg'
label define secbem 0 "Country-wide OWW wage", modify
rename sec_bem _rowname
save "tex/desc/wagediffs/diffsger`tlogyr'-$waglvl", replace
* matload diffsger`tlogyr', p(tex/desc/wagediffs) over dropall missing(.)
qui do "$root/conc/secbem.do"


* Wage differential in year of selection estimation (1996)
*---------------------------------------------------------
use "$root/wages/destatis-gearn-defl", clear
keep if year==${selyear}
drop agearn year
rename nace11 nace1
* replace missing with mean aggregate sector wage
gen byte _aggsec = int(nace1/10)
egen _agearn = mean(agearn), by(_aggsec)
replace agearn = _agearn if agearn==.
drop _*
* merge in countries
qui count
local obs = `r(N)'
expand 4
sort nace1
gen cntrybemgrp = _n - int(_n/4-.1)*4
sort cntrybemgrp
merge cntrybemgrp using `cntrgrp_med_wage_`selyr''
tab _merge
drop _merge
* wagediffs and German ln wages
gen wagediff=cntrgrp_wage/agearn_med
gen owwdiff =cntrgrp_wage/home_wage_par
label var wagediff "cntrgrp_wage/agearn_med"
label var owwdiff  "cntrgrp_wage/home_w"
gen ln_wagediff=ln(wagediff)
gen ln_owwdiff=ln(wagediff)
label var ln_wagediff "ln(cntrgrp_wage/agearn_med)"
label var ln_owwdiff "ln(cntrgrp_wage/home_w)"
local i 0
foreach var in wagediff ln_wagediff owwdiff ln_owwdiff {
  local i = `i' + 1
  local lbl`i' : variable label `var'
  }
replace agearn_med = ln(agearn_med)
rename agearn_med w_HOM
label var w_HOM "ln Sectoral median wage"
keep nace1 cntrybemgrp wagediff ln_wagediff owwdiff ln_owwdiff w_HOM
preserve
  gen year=${selyear}
  sort year cntrybemgrp nace1
  save ${bef_reshape_${selyear}}
restore
reshape wide wagediff ln_wagediff owwdiff ln_owwdiff, i(nace1 w_HOM) j(cntrybemgrp)
local x=0
foreach name in $regagg {
  local x=`x'+1
  local i 0
  foreach var in wagediff ln_wagediff owwdiff ln_owwdiff {
    local i = `i' + 1
    rename `var'`x' `var'_`name' 
    label var `var'_`name' "`lbl`i'' `name'"
    }
  }
sort nace1
save ${wage_diff_${selyear}}
* aggregate reporting with table
rename nace1 nace11_code
sort nace11_code
merge nace11_code using "$root/conc/nace2bem", nokeep
collapse (mean) wagediff* owwdiff*, by(sec_bem) fast
keep sec_bem wagediff* owwdiff*
preserve 
  tempfile appndsel
  keep sec_bem owwdiff*
  keep in 1
  foreach reg in $regagg {
    rename owwdiff_`reg' wagediff_`reg'
    }
  replace sec_bem = 0
  save `appndsel'
restore
keep sec_bem wagediff*
append using `appndsel'
label define secbem 0 "Country-wide OWW wage", modify
rename sec_bem _rowname
save "tex/desc/wagediffs/diffsger`selyr'-$waglvl", replace
* matload diffsger`selyr', p(tex/desc/wagediffs) over dropall missing(.)
qui do "$root/conc/secbem.do"
