*! version 1.2.8  14nov2006  by Marc Muendler muendler@ucsd.edu

/* Varcov correction assumes that selection equations have constant */
/* Selection equation assumed to have constant as last regressor */
/* Varcov correction assumes that sureg equations do not have constant (add a regressor called ones if constant needed) */
/* Sure equation assumed to have Mills ratio as last regressor */
/* Regional wages are supposed to be first (5) regressors in SUR equations */

clear
set memory 400m
set matsize 800
set more off
capture log close

cd "$rootslct"

log using "logs/translog-selct-2stp-$waglvl-pt$par-af$aff-cf-semiparam-allyrs.log", replace

*----------------------following code identical to translog-selct-2stp-cf-semiparam.do------------------------------------------
*-----substitute: /v3spfs for /v3sp, now for 00, ${yrdiff}yrlg for 96, mneid year for mneid -----------------------------------------------------
*-----substitute: Xdata/mneid-fortwoway-$waglvl-pt$par-af$aff-cf-semiparam-allyrs for Xdata/mneid-fortwoway-$waglvl-pt$par-af$aff-cf-semiparam --
*-----substitute: Xdata/mneid-forbstrap-$waglvl-pt$par-af$aff-cf-semiparam-allyrs for Xdata/mneid-forbstrap-$waglvl-pt$par-af$aff-cf-semiparam --

mat drop _all

local maxiter $maxiter
local usexvar $usexvar  /* selection regressor varlist to be used for selectivity correction in sureg */
local maxvars 4  /* longest used selection regressor varlist */
local surxno 15  /* number of SURE regressors per equation (excluding noFDI indicators, excluding adj. constant/ones and excluding propensity scores) */

adopath + "$root/%stata/ado"

#delimit ;


/* define X-equation restrictions */
/*--------------------------------*/

* constraint define  1 [sCE]cf_wHO = [sHO]cf_wCE;
  constraint define  2 [sCE]cf_wDE = [sDE]cf_wCE;
  constraint define  3 [sCE]cf_wOI = [sOI]cf_wCE;
  constraint define  4 [sCE]cf_wWE = [sWE]cf_wCE;
* constraint define  5 [sDE]cf_wHO = [sHO]cf_wDE;
  constraint define  6 [sDE]cf_wOI = [sOI]cf_wDE;
  constraint define  7 [sDE]cf_wWE = [sWE]cf_wDE;
* constraint define  8 [sOI]cf_wHO = [sHO]cf_wOI;
  constraint define  9 [sOI]cf_wWE = [sWE]cf_wOI;
* constraint define 10 [sWE]cf_wHO = [sHO]cf_wWE;
* constraint define 11 [sHO]cf_wHO + [sHO]cf_wCE + [sHO]cf_wDE + [sHO]cf_wOI + [sHO]cf_wWE = 0;
  constraint define 12 [sCE]cf_wHO + [sCE]cf_wCE + [sCE]cf_wDE + [sCE]cf_wOI + [sCE]cf_wWE = 0;
  constraint define 13 [sDE]cf_wHO + [sDE]cf_wCE + [sDE]cf_wDE + [sDE]cf_wOI + [sDE]cf_wWE = 0;
  constraint define 14 [sOI]cf_wHO + [sOI]cf_wCE + [sOI]cf_wDE + [sOI]cf_wOI + [sOI]cf_wWE = 0;
  constraint define 15 [sWE]cf_wHO + [sWE]cf_wCE + [sWE]cf_wDE + [sWE]cf_wOI + [sWE]cf_wWE = 0;

/* With 5 regions, there are (5*5-5)/2=10 symmetry restrictions in principle. 
   However, one equation drops due to further cross-equation constraints, 
   only 6 of the symmetry restrictions are needed.
   Similarly, only 4 of the 5 restrictions on wage parameter sums are needed. */


/* variable sets for probit estimation */
/*-------------------------------------*/

do $dp/!varsets-sp.do;

/* nonparametric base variables for sureg estimation */
/*---------------------------------------------------*/

local pscores "pscCE pscDE pscOI pscWE"; /* first-order terms */
local regord = trim(subinstr("`pscores'","psc","",.));
local pscser2 ""; /* second-order terms */
local cnt 0;
foreach reg in `regord' {;
  local cnt = `cnt' + 1;
  local r2dg = substr("`reg'",1,2);
  tokenize `pscores';
  local pscno : word count `pscores';
  forvalues i = `cnt'/`pscno' {;
    local addtrm "``i''_`r2dg'";
    local pscser2 "`pscser2' `addtrm'";
    };
  };
local pscser3 ""; /* third-order terms */
local cnt 1;
local strt 0;
foreach reg in `regord' {;
  local strt = `strt' + `cnt';
  local r2dg = substr("`reg'",1,2);
  tokenize `pscser2';
  local pscno : word count `pscser2';
  local cnt 0;
  forvalues i = `strt'/`pscno' {;
    * if length(subinstr("``i''",substr("``i''",-2,2),"",.))==4 {; /* operate only on square terms, not in general on interaction terms */
    if substr("``i''",-2,2)=="`r2dg'"  local cnt = `cnt' + 1;
    local addtrm "``i''_`r2dg'";
    local pscser3 "`pscser3' `addtrm'";
    * };
    };
  };
local pscser "`pscores'`pscser2'`pscser3'";
disp "`pscser'";
local pscno : word count `pscser';
disp "`pscno'";

/* data and main loop */
/*--------------------*/

local howmany "";
if index("$howmany","1")~=0  local howmany 1;  /* only usemissg 1 permitted */
foreach usemissg in `howmany' {; /* begin `usemissg' loop */

capture mkdir "$rootslct/tex/v3spfs";
capture mkdir "$rootslct/estmat/v3spfs";
capture mkdir "$rootslct/tex/v3spfs/pt$par-af$aff-$waglvl-cf";
capture mkdir "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf";
capture mkdir "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/byreg";
capture mkdir "$rootslct/estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'";

*----------------------above code identical to translog-selct-2stp-cf-semiparam.do---------------------------------------------;


use "$rootslct/Xdata/mneid-regdata-d$yrdiff-$waglvl-pt$par-af$aff-cf", clear;
drop ln_inter_now;
rename ln_inter_${yrdiff} ln_inter;


*----------------------following code identical to translog-selct-2stp-cf-semiparam.do-----------------------------------------------------------;
*-----substitute: /v3spfsfs for /v3spfs, now for 00, ${yrdiff}yrlg for 96, mneid year for mneid -----------------------------------------------------;
*-----substitute: Xdata/mneid-fortwoway-$waglvl-pt$par-af$aff-cf-semiparam-allyrs for Xdata/mneid-fortwoway-$waglvl-pt$par-af$aff-cf-semiparam --
*-----substitute: Xdata/mneid-forbstrap-$waglvl-pt$par-af$aff-cf-semiparam-allyrs for Xdata/mneid-forbstrap-$waglvl-pt$par-af$aff-cf-semiparam --

* sector dummies;
qui summ sec1_bem;
local minsec = `r(min)'+1;
local maxsec = `r(max)';
local dumlst = "_Isec1_bem_`minsec'";
local secdum = "_b[_Isec1_bem_`minsec']*_Isec1_bem_`minsec'";
local secavgdum = "_b[_Isec1_bem_`minsec']*_MN_Isec1_bem_`minsec'";
local minsec = `minsec' + 1;
forvalues j = `minsec'/`maxsec' {;
  local dumlst "`dumlst' _Isec1_bem_`j'";
  local secdum "`secdum' + _b[_Isec1_bem_`j']*_Isec1_bem_`j'";
  local secavgdum "`secavgdum' + _b[_Isec1_bem_`j']*_MN_Isec1_bem_`j'";
  };

* matrices for marginal effects of wages on selection and of propensity scores on labor demand;
mat pscdlnw = J(4,5,.);
mat suredps = J(4,4,.);
matrix rownames pscdlnw = $regagg;
matrix rownames suredps = $regagg;
matrix colnames pscdlnw = HOM $regagg;
matrix colnames suredps = $regagg;
local rownames : rowfullnames pscdlnw;
local rownum : word count `rownames';
tokenize `rownames';
forvalues rowi = 1/`rownum' {;
  local rownew = "i_" + substr("``rowi''",-3,3);
  matname pscdlnw `rownew', rows(`rowi') explicit;
  local rownew = "y_" + substr("``rowi''",-3,3);
  matname suredps `rownew', rows(`rowi') explicit;
  };
local colnames : colfullnames pscdlnw;
local colnum : word count `colnames';
tokenize `colnames';
forvalues coli = 1/`colnum' {;
  local colnew = "w_" + substr("``coli''",-3,3);
  matname pscdlnw `colnew', columns(`coli') explicit;
  };
local colnames : colfullnames suredps;
local colnum : word count `colnames';
tokenize `colnames';
forvalues coli = 1/`colnum' {;
  local colnew = "ps_" + substr("``coli''",-3,3);
  matname suredps `colnew', columns(`coli') explicit;
  };
    

/* first step: probit estimation */
/*-------------------------------*/

local xvars `usexvar';
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);

  * probit regressions without sector dummies (used for translog);
  * qui reg i`r2dg'now iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg ${parsp_`xvars'};
  * qui predict linres`r2dg', res;
  dprobit i`r2dg'now iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg ${parsp_`xvars'}, asis iterate(`maxiter');
  est2vec dprobit`r2dg', vars(iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg ${parsp_`xvars'} _Isec1_bem_1 _Isec1_bem_2 _Isec1_bem_3 _Isec1_bem_4 _Isec1_bem_5 _Isec1_bem_6 _Isec1_bem_7 _Isec1_bem_8 _Isec1_bem_9 _cons) e(N ll chi2 df_m r2_p pbar xbar) name(`r2dg'`xvars') altvec(dfdx se_dfdx);

  * predict propensity scores from probit regression without sector dummies;
  * only xvars = `usexvar' used for second stage;
    predict double psc`r2dg', p;
    label var psc`r2dg' "Propensity score `r2dg' (xvars `xvars')";
  };

  * build matrix pscdlnw of probit wage coefficients;
  foreach type in b se {;  /* Build up pscdlnw columns in order of $regagg */
    foreach reg in $regagg {;
      local r2dg = substr("`reg'",1,2);
      tempname plnw`r2dg';
      matins dprobit`r2dg'_`type', matrix(`plnw`r2dg'') ifr(w_HOM w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU) over;
      };
    local cols : word count $regagg;
    tokenize $regagg;
    local j 1;
    local `j' = substr("``j''",1,2);
    mat pscdlnw_`type' = `plnw``j''';
    forvalues j = 2/`cols' {;
      local `j' = substr("``j''",1,2);
      mat pscdlnw_`type' = pscdlnw_`type' , `plnw``j''';
      };
    matrix colnames pscdlnw_`type' = $regagg;
    };
  * do not replace missing and insignificant with 0;
  * local regj = 0;
  * foreach reg in $regagg {;
  *   local regj = `regj' + 1;
  *   local wi = 0;
  *   foreach weff in HOM $regagg {;
  *     local wi = `wi' + 1;
  *     if pscdlnw_b[`wi',`regj'] == -999 | pscdlnw_b[`wi',`regj'] == . | pscdlnw_se[`wi',`regj'] == -999 | pscdlnw_se[`wi',`regj'] == . | abs(pscdlnw_b[`wi',`regj']/pscdlnw_se[`wi',`regj']) < abs(invnorm((100-${S_level})/200)) {;
  *       mat pscdlnw_b[`wi',`regj'] = 0;
  *       };
  *     };
  *   };
  mat pscdlnw = pscdlnw_b;
  mat drop pscdlnw_b;
  mat pscdlnw = pscdlnw '; /* regions in rows, wage effects in columns */
  mat pscdlnw_se = pscdlnw_se ';
  local rownames : rowfullnames pscdlnw;
  local colnames : colfullnames pscdlnw;
  local rownum : word count `rownames';
  local colnum : word count `colnames';
  tokenize `rownames';
  forvalues rowi = 1/`rownum' {;
    local rownew = "i_" + substr("``rowi''",-3,3);
    matname pscdlnw `rownew', rows(`rowi') explicit;
    matname pscdlnw_se `rownew', rows(`rowi') explicit;
    };
  tokenize `colnames';
  forvalues coli = 1/`colnum' {;
    local colnew = "w_" + substr("``coli''",-3,3);
    matname pscdlnw `colnew', columns(`coli') explicit;
    matname pscdlnw_se `colnew', columns(`coli') explicit;
    };
  disp in gr "Matrix of wage effects on FDI presence (usemissg: " in ye `usemissg' in gr ")";
  mat list pscdlnw;

* evaluation of wage effects;
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  foreach wreg in HOM $regagg {;
    local w2dg = substr("`wreg'",1,2);
    local dfm = dprobit`r2dg'_e[rownumb(dprobit`r2dg'_e,"e(df_m)"),colnumb(dprobit`r2dg'_e,"`r2dg'`xvars'")];
    qui gen double dpsc`r2dg'dw`w2dg' = pscdlnw[rownumb(pscdlnw,"i_`reg'"),colnumb(pscdlnw,"w_`wreg'")];
    qui gen byte dpsc`r2dg'dw`w2dg'_lcl = dpsc`r2dg'dw`w2dg' - invttail(`dfm',((100-${S_level})/200)) * pscdlnw_se[rownumb(pscdlnw_se,"i_`reg'"),colnumb(pscdlnw_se,"w_`wreg'")];
    qui gen byte dpsc`r2dg'dw`w2dg'_ucl = dpsc`r2dg'dw`w2dg' + invttail(`dfm',((100-${S_level})/200)) * pscdlnw_se[rownumb(pscdlnw_se,"i_`reg'"),colnumb(pscdlnw_se,"w_`wreg'")];
    };
  };
* summ dpsc*;
mat drop pscdlnw_se;

* Save data for bootstrap routine;
preserve;
  drop dpsc`r2dg'dw`w2dg'*;
  sort mneid year;
  save "$rootslct/Xdata/mneid-forbstrap-$waglvl-pt$par-af$aff-cf-semiparam-allyrs", replace;
restore;

* Generate polynomial interaction terms for sureg regression;
foreach var of local pscser {;
  if length("`var'")>5 {;
    local term = subinstr("`var'","_","*psc",.);
    qui gen double `var' = `term';
    label var `var' "(`term' for sureg)";
    };
  };


/* second step: seemingly unrelated regressions with semiparametric error terms */
/*-----------------------------------------------------------------------------*/

if `usemissg' == 0 {;
sureg (sCE: yCE = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE cfCE `pscser')
      (sDE: yDE = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE cfDE `pscser')
      (sOI: yOI = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE cfOI `pscser')
      (sWE: yWE = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE cfWE `pscser')
      , constraints(2 3 4 6 7 9 12 13 14 15) corr isur iterate(`maxiter');
*     (sHO: yHO = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE cfHO `pscser'); /* left-out equation */
};

if `usemissg' == 1 {;
sureg (sCE: yCE = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE nofdiDE nofdiOI nofdiWE cfCE `pscser')
      (sDE: yDE = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE nofdiCE nofdiOI nofdiWE cfDE `pscser')
      (sOI: yOI = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE nofdiCE nofdiDE nofdiWE cfOI `pscser')
      (sWE: yWE = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE nofdiCE nofdiDE nofdiOI cfWE `pscser')
      , constraints(2 3 4 6 7 9 12 13 14 15) corr isur iterate(`maxiter');
*     (sHO: yHO = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE nofdiCE nofdiDE nofdiOI nofdiWE cfHO `pscser'); /* left-out equation */
};

est2vec translog`usemissg', e(N rss k_eq levels chi2_bp df_bp r2_1 chi2_1 p_1 r2_2 chi2_2 p_2 r2_3 chi2_3 p_3 r2_4 chi2_4 p_4) name(translog_`usemissg');

if `usemissg' == 0 {;
  order mneid year sHO kHO tHO wHO cfHO sCE kCE tCE wCE cfCE sDE kDE tDE wDE cfDE sOI kOI tOI wOI cfOI sWE kWE tWE wWE cfWE;
  };
if `usemissg' == 1 {;
  order mneid year sHO kHO tHO wHO nofdiHO cfHO sCE kCE tCE wCE nofdiCE cfCE sDE kDE tDE wDE nofdiDE cfDE sOI kOI tOI wOI nofdiOI cfOI sWE kWE tWE wWE nofdiWE cfWE;
  };

* observation-specific predictions for extensive margins, sureg part;
*   operate on: pscCE pscDE pscOI pscWE;
*          and  pscCE_CE pscDE_CE pscOI_CE pscWE_CE pscDE_DE pscOI_DE pscWE_DE pscOI_OI pscWE_OI pscWE_WE;
*          and  pscCE_CE_CE pscDE_CE_CE pscOI_CE_CE pscWE_CE_CE pscDE_DE_CE pscOI_DE_CE pscWE_DE_CE pscOI_OI_CE pscWE_OI_CE pscWE_WE_CE pscDE_DE_DE pscOI_DE_DE pscWE_DE_DE pscOI_OI_DE pscWE_OI_DE pscWE_WE_DE pscOI_OI_OI pscWE_OI_OI pscWE_WE_OI pscWE_WE_WE;
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  * Evaluation of selection effects;
  foreach wreg in $regagg {;
    local w2dg = substr("`wreg'",1,2);
    local pspredacc "_b[s`r2dg':_cons]"; 
    local psrestacc "0";
    local psrestavgacc "0";
    local pspredacc "`pspredacc' + _b[s`r2dg':psc`w2dg']*psc`w2dg'";
    local psmatacc "_b[s`r2dg':psc`w2dg']";
    tokenize `pscser'; 
    local regrno : word count `pscser';
    forvalues i = 1/`regrno' {;
      egen double _MN``i'' = mean(``i'');
      };
    forvalues i = 1/`regrno' {;
      if length(subinstr("``i''","`w2dg'","",.)) == length("``i''")-6 {; /* regional variable appears in cubic term: treat */
        local pspredacc "`pspredacc' + _b[s`r2dg':``i'']*psc`w2dg'*psc`w2dg'*psc`w2dg'";
        local psmatacc "`psmatacc' + 3*_b[s`r2dg':``i'']*psc`w2dg'*psc`w2dg'";
        };
      if length(subinstr("``i''","`w2dg'","",.)) == length("``i''")-4 & lower(subinstr("``i''","`w2dg'","",.))~=subinstr("``i''","`w2dg'","",.) {; /* regional variable appears in third-order interaction term: treat */
        local covar = subinstr(subinstr("``i''","`w2dg'","",.),"_","",.);
        local pspredacc "`pspredacc' + _b[s`r2dg':``i'']*_MN`covar'*psc`w2dg'*psc`w2dg'";
        local psmatacc "`psmatacc' + 2*_b[s`r2dg':``i'']*_MN`covar'*psc`w2dg'";
        };
      if length(subinstr("``i''","`w2dg'","",.)) == length("``i''")-2 & lower(subinstr("``i''","`w2dg'","",.))~=subinstr("``i''","`w2dg'","",.) {; /* regional variable appears in second-order interaction term: treat */
        local covar1 = "psc" + substr(subinstr(subinstr("``i''","`w2dg'","",.),"_","",.),4,2);
        local covar2 = "psc" + substr(subinstr(subinstr("``i''","`w2dg'","",.),"_","",.),6,2);
        if "`covar2'"=="psc" {;
          local pspredacc "`pspredacc' + _b[s`r2dg':``i'']*_MN`covar1'*psc`w2dg'";
          local psmatacc "`psmatacc' + _b[s`r2dg':``i'']*_MN`covar1'";
          };
        if "`covar2'"~="psc" {;
          local pspredacc "`pspredacc' + _b[s`r2dg':``i'']*_MN`covar1'*_MN`covar2'*psc`w2dg'";
          local psmatacc "`psmatacc' + _b[s`r2dg':``i'']*_MN`covar1'*_MN`covar2'";
          };
        };
      if length(subinstr("``i''","`w2dg'","",.)) == length("``i''") {; /* regional variable does not appear in term: store for mean subtraction */
        local psrestacc "`psrestacc' + _b[``i'']*``i''";
        local psrestavgacc "`psrestavgacc' + _b[``i'']*_MN``i''";
        };
      };     
    * disp in yellow "`pspredacc'"; * disp in yellow "`psrestacc'"; * disp in yellow "`psrestavgacc'";
    qui gen double dy`r2dg'dps`w2dg' = `pspredacc' + `psrestavgacc' if e(sample);
    qui gen double _mdy`r2dg'psc`w2dg' = `psmatacc' if e(sample);
    qui summ _mdy`r2dg'psc`w2dg', meanonly;
    mat suredps[rownumb(suredps,"y_`reg'"),colnumb(suredps,"ps_`wreg'")] = `r(mean)';
    * CIs from SE of prediction (default);
    qui gen double dy`r2dg'dps`w2dg'_se = y`r2dg' - dy`r2dg'dps`w2dg' + `psrestavgacc' - `psrestacc' if e(sample);
    qui gen double dy`r2dg'dps`w2dg'_lcl = dy`r2dg'dps`w2dg' - invttail(e(df_m1),((100-${S_level})/200)) * dy`r2dg'dps`w2dg'_se if e(sample);
    qui gen double dy`r2dg'dps`w2dg'_ucl = dy`r2dg'dps`w2dg' + invttail(e(df_m1),((100-${S_level})/200)) * dy`r2dg'dps`w2dg'_se if e(sample);
    label var dy`r2dg'dps`w2dg' "Selection i`w2dg' effect on labor demand y`r2dg'";
    label var dy`r2dg'dps`w2dg'_lcl "${S_level}% CI i`w2dg' eff on empl y`r2dg'";
    label var dy`r2dg'dps`w2dg'_ucl "${S_level}% CI i`w2dg' eff on empl y`r2dg'";
    * sort psc`w2dg';
    * twoway connected dy`r2dg'dps`w2dg' dy`r2dg'dps`w2dg'_lcl dy`r2dg'dps`w2dg'_ucl psc`w2dg' if psc`w2dg'>=0 & psc`w2dg'<=1;
    * twoway connected dy`r2dg'dps`w2dg' psc`w2dg' if psc`w2dg'>=0 & psc`w2dg'<=1;
    drop _MN* dy`r2dg'dps`w2dg'_se;
    * drop _mdy`r2dg'psc`w2dg'; 
    }; /* close wreg loop */
  }; /* close reg loop */

sort mneid year;
disp in gr "Matrix of selection effects on labor demand (usemissg: " in ye `usemissg' in gr ")";
mat list suredps;


/* initial concavity checks */
/*--------------------------*/

* matrix to check (i) that the fitted cost shares sLOC_predicted are nonnegative;
mat negxhatcnt`usemissg' = J(2,4,.);
matname negxhatcnt`usemissg' r(N_neg_xhare) r(N), rows(1..2) explicit;
local i = 0;
foreach sreg in sCE sDE sOI sWE {;
  local i = `i' + 1;
  matname negxhatcnt`usemissg' `sreg', columns(`i') explicit;
  predict _`sreg' if e(sample), equation(`sreg') xb;
  qui count if _`sreg'<0 & e(sample);
  mat negxhatcnt`usemissg'[1,`i']=`r(N)';
  qui count if e(sample);
  mat negxhatcnt`usemissg'[2,`i']=`r(N)';
  };
drop _s*;


/* sample statistics for elasticities of substitution */
/*----------------------------------------------------*/

order mneid year nreg sec1_bem i*;
summ2tex * if e(sample), c(mean sd N p50) name(summ_translog`usemissg') p(tex/v3spfs/pt$par-af$aff-$waglvl-cf) replace detail;
preserve;
  foreach var in sHO sCE sDE sOI sWE wHO wCE wDE wOI wWE tHO tCE tDE tOI tWE kHO kCE kDE kOI kWE cfHO cfCE cfDE cfWE cfOI {;
    replace `var' = . if `var'==0;
    };
  summ2tex * if e(sample), c(mean sd N p50) name(summ_translog`usemissg'_missg) p(tex/v3spfs/pt$par-af$aff-$waglvl-cf) replace detail;
  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    summ2tex * if e(sample) & nofdi`r2dg'==0, c(mean sd N p50) name(summ_translog`usemissg'_missg`r2dg') p(tex/v3spfs/pt$par-af$aff-$waglvl-cf) replace detail;
    };
restore;
corr2tex sHO sCE sDE sOI sWE if e(sample), name(corrT_translog`usemissg') p(tex/v3spfs/pt$par-af$aff-$waglvl-cf) replace;


/* elasticities of substitution */
/*------------------------------*/

* Cross-wage coefficient matrix;
tempname VCE; /* resets prior `VCE' if defined */
tempname bcoef bse coefmat0 semat0 coefmat1 semat1 coefmat2 semat2 coefmat3 semat3 coefmat4 semat4; 
mat `bcoef' = e(b)';
mat `VCE' = e(V);  /* Heckman corrected if positive semi-definite under re-run */
mat `bse' = vecdiag(`VCE')';
* mat `bse' = vecdiag(`VCEkeep')'; /* Permit checking for symmetry in absence of Heckman correction */
foreach mattyp in coef se {;
  mat ``mattyp'mat0' = J(5,1,.);
  local cnt 0;
  foreach reg in $regagg {;
    local cnt = `cnt' + 1;
    local r2dg = substr("`reg'",1,2);
    matorder `b`mattyp'', m(``mattyp'mat`cnt'') ifr(s`r2dg':cf_wHO s`r2dg':cf_wCE s`r2dg':cf_wDE s`r2dg':cf_wOI s`r2dg':cf_wWE);
    local col`cnt' : roweq ``mattyp'mat`cnt''; local col`cnt' = substr("`col`cnt''",1,3);
    };
  * mat list ``mattyp'mat1';
  * mat list ``mattyp'mat2';
  * mat list ``mattyp'mat3';
  * mat list ``mattyp'mat4';
  mat `mattyp'mat = ``mattyp'mat0' , ``mattyp'mat1' , ``mattyp'mat2' , ``mattyp'mat3' , ``mattyp'mat4';
  * mat list `mattyp'mat;
  mat ``mattyp'mat0' = `mattyp'mat[1,1..5] ';
  mat `mattyp'mat = ``mattyp'mat0' , ``mattyp'mat1' , ``mattyp'mat2' , ``mattyp'mat3' , ``mattyp'mat4';
  mat `mattyp'mat[1,1] = - (`mattyp'mat[2,1] + `mattyp'mat[3,1] + `mattyp'mat[4,1] + `mattyp'mat[5,1]);
  local collbl = subinstr("wHO `col1' `col2' `col3' `col4'","s","w",.);
  local rowlbl = "sHO `col1' `col2' `col3' `col4'";
  * disp "`collbl'";
  * disp "`rowlbl'";
  matname `mattyp'mat `collbl', columns(1..5) explicit;
  matname `mattyp'mat `rowlbl', rows(1..5) explicit;
};
* standard error for sHOwHO;
local sdHOHO = 0;
forvalues i = 2/5 {;
  forvalues j = 2/5 {;
    local sdHOHO = `sdHOHO' + semat[`i',`j'];
    };
  };
mat semat[1,1] = sqrt(`sdHOHO');
mat list coefmat; mat list semat;

* Observation-specific extensive margins;
tempname suredlnw;
mat `suredlnw' = suredps * pscdlnw;
foreach weff in HOM $regagg {;
  local w2dg = substr("`weff'",1,2);
  gen double xmrHOw`w2dg' = 0;
  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    local regvar = "w_othr_`weff'";
    if "`weff'"=="HOM"  local regvar = "w_`weff'";
    local dpsc`r2dg'dw`w2dg' = `suredlnw'[rownumb(`suredlnw',"y_`reg'"),colnumb(`suredlnw',"w_`weff'")];
    * qui gen double xmr`r2dg'w`w2dg' = (_mdy`r2dg'pscCE*_mpscCEw`w2dg' + _mdy`r2dg'pscDE*_mpscDEw`w2dg' + _mdy`r2dg'pscOI*_mpscOIw`w2dg' + _mdy`r2dg'pscWE*_mpscWEw`w2dg') * i`r2dg'now / cf`r2dg' ; /* if log wages used; observations */
    * qui gen double xmr`r2dg'w`w2dg' = (_mdy`r2dg'pscCE*_mpscCEw`w2dg' + _mdy`r2dg'pscDE*_mpscDEw`w2dg' + _mdy`r2dg'pscOI*_mpscOIw`w2dg' + _mdy`r2dg'pscWE*_mpscWEw`w2dg') * i`r2dg'now * `regvar' / cf`r2dg' ; /* if plain wages used; observations */
    * qui gen double xmr`r2dg'w`w2dg' = `dpsc`r2dg'dw`w2dg'' * i`r2dg'now / cf`r2dg' ; /* if log wages used; mean matrix */
    qui gen double xmr`r2dg'w`w2dg' = `dpsc`r2dg'dw`w2dg'' * i`r2dg'now * `regvar' / cf`r2dg' ; /* if plain wages used; mean matrix */
    replace xmr`r2dg'w`w2dg'=. if abs(xmr`r2dg'w`w2dg')>1;  /* disregard implausible outliers */
    };
  };

* Save predictions by observation for twoway plots;
preserve;
  keep mneid year dpsc??dw?? dpsc??dw??_lcl dpsc??dw??_ucl dy??dps?? dy??dps??_lcl dy??dps??_ucl xmr??w?? w_* psc??;
  sort mneid year;
  if `usemissg'==1  save "$rootslct/Xdata/mneid-fortwoway-$waglvl-pt$par-af$aff-cf-semiparam-allyrs", replace;
restore;

* Matrix of mean extensive margin correction terms;
capture mat drop xmrmat;
local rownames : rowfullnames coefmat;  /* Match regional pattern in coefmat at intensive margin */
local colnames : colfullnames coefmat;
local colnum : word count `colnames';
foreach reg in `rownames' {;
  local r2dg = substr("`reg'",-2,2);
  tempname xmat`r2dg';
  mat `xmat`r2dg'' = J(1,`colnum',.);
  matname `xmat`r2dg'' s`r2dg', rows(1) explicit;
  local colj = 0;
  foreach weff in `colnames' {;
    local colj = `colj' + 1;
    qui summ xmr`r2dg'`weff' if s`r2dg'~=0 & e(sample), meanonly;  /* only calculate mean over sample MNEs with presence */
    mat `xmat`r2dg''[1,`colj'] = r(mean);
    matname `xmat`r2dg'' `weff', columns(`colj') explicit;
    };
  capture mat xmrmat = xmrmat \ `xmat`r2dg'';
  if _rc {;
    mat xmrmat = `xmat`r2dg'';
    };
  };
foreach reg in `rownames' {;
  local r2dg = substr("`reg'",-2,2);
  disp; 
  disp "Coefficient on own-region propensity score in `r2dg': `pstrlg`r2dg''";
  disp "Extensive margin correction terms for `r2dg'";
  summ xmr`r2dg'w* if s`r2dg'~=0 & e(sample);
  };
mat list xmrmat;

* Statistics for matrices of shares (predicted shares recommended by Berndt 1991 and Hayashi 2000 but not used);
local eqs = subinstr("`rownames'","sHO","",.);
foreach reg in `eqs' {;
  local r2dg = substr("`reg'",-2,2);
  * qui predict double shat`r2dg', equation(s`r2dg') xb, if e(sample);
  gen double shat`r2dg' = s`r2dg';
  };
gen double shatHO = sHO;
preserve;
collapse (mean) shatHO shatCE shatDE shatOI shatWE if e(sample), fast;
mkmat shatHO shatCE shatDE shatOI shatWE, matrix(Tmat);  /* Tmat to be transposed to a column vector below */
matname Tmat theta, rows(1) explicit;
restore, preserve;
collapse (sd) shatHO shatCE shatDE shatOI shatWE if e(sample), fast;
mkmat shatHO shatCE shatDE shatOI shatWE, matrix(Tmat_sd);
matname Tmat_sd theta_sd, rows(1) explicit;
restore, preserve;
collapse (count) shatHO shatCE shatDE shatOI shatWE if e(sample), fast;
mkmat shatHO shatCE shatDE shatOI shatWE, matrix(Tmat_N);
matname Tmat_N theta_N, rows(1) explicit;
restore, preserve;

* Zeta matrix (r2 in Anderson and Thursby 1986);
foreach sreg in HOM $regagg {;
  local sr2dg = substr("`sreg'",1,2);
  foreach wreg in HOM $regagg {;
    local wr2dg = substr("`wreg'",1,2);
    qui gen double r2s`sr2dg's`wr2dg' = Tmat_N[1,colnumb(Tmat_N,"s`sr2dg'")]^(-3) * ( ( s`sr2dg' - Tmat[1,colnumb(Tmat,"s`sr2dg'")] ) * ( s`sr2dg'*s`wr2dg' - Tmat[1,colnumb(Tmat,"s`sr2dg'")]*Tmat[1,colnumb(Tmat,"s`wr2dg'")] - corrT_translog`usemissg'_tbl[rownumb(corrT_translog`usemissg'_tbl,"s`sr2dg'"),colnumb(corrT_translog`usemissg'_tbl,"s`wr2dg'")]*Tmat_sd[1,colnumb(Tmat_sd,"s`sr2dg'")]*Tmat_sd[1,colnumb(Tmat_sd,"s`wr2dg'")] ) + Tmat_N[1,colnumb(Tmat_N,"s`sr2dg'")]*(Tmat_N[1,colnumb(Tmat_N,"s`sr2dg'")] - 1)*Tmat[1,colnumb(Tmat,"s`sr2dg'")]*Tmat_sd[1,colnumb(Tmat_sd,"s`sr2dg'")]*( Tmat_sd[1,colnumb(Tmat_sd,"s`sr2dg'")] + corrT_translog`usemissg'_tbl[rownumb(corrT_translog`usemissg'_tbl,"s`sr2dg'"),colnumb(corrT_translog`usemissg'_tbl,"s`wr2dg'")]*Tmat_sd[1,colnumb(Tmat_sd,"s`wr2dg'")] ) );
    };
  };
collapse (sum) r2sHOsHO r2sHOsCE r2sHOsDE r2sHOsOI r2sHOsWE r2sCEsHO r2sCEsCE r2sCEsDE r2sCEsOI r2sCEsWE r2sDEsHO r2sDEsCE r2sDEsDE r2sDEsOI r2sDEsWE r2sOIsHO r2sOIsCE r2sOIsDE r2sOIsOI r2sOIsWE r2sWEsHO r2sWEsCE r2sWEsDE r2sWEsOI r2sWEsWE if e(sample), fast;
tempname zetatmp;
mkmat r2sHOsHO r2sHOsCE r2sHOsDE r2sHOsOI r2sHOsWE r2sCEsHO r2sCEsCE r2sCEsDE r2sCEsOI r2sCEsWE r2sDEsHO r2sDEsCE r2sDEsDE r2sDEsOI r2sDEsWE r2sOIsHO r2sOIsCE r2sOIsDE r2sOIsOI r2sOIsWE r2sWEsHO r2sWEsCE r2sWEsDE r2sWEsOI r2sWEsWE, matrix(`zetatmp');
local shnames : colfullnames Tmat;
local shnames = subinstr("`shnames'","hat","",.);
mat zetamat = J(5,5,.);
matname zetamat `shnames', rows(1..5) explicit;
matname zetamat `shnames', columns(1..5) explicit;
foreach sr in `shnames' {;
  local sr2dg = subinstr("`sr'","s","",.);
  foreach wr in `shnames' {;
    local wr2dg = subinstr("`wr'","s","",.);
    mat zetamat[rownumb(zetamat,"`sr'"),colnumb(zetamat,"`wr'")] = `zetatmp'[1,colnumb(`zetatmp',"r2s`sr2dg's`wr2dg'")];
    };
  };
restore;

* Matrices of shares;
mat Tmat_all = Tmat \ Tmat_sd \ Tmat_N;
mat Tmat = Tmat'; /* Tmat transposed to a column vector */
mat Tsqmat = Tmat * Tmat';

* Calculate total cross-price elasticities (both margins);
mat TotElast = coefmat + xmrmat + Tsqmat;
forvalues r = 2/5 {; /* Fill lower-echelon entries */
local maxcol = `r'-1;
  forvalues m = 1/`maxcol' {;
    mat TotElast[`r',`m'] = TotElast[`r',`m'] / Tmat[`r',1];
    };
  };
forvalues m = 2/5 {; /* Fill upper-echelon entries */
local maxrow = `m'-1;
  forvalues r = 1/`maxrow' {;
    mat TotElast[`r',`m'] = TotElast[`r',`m'] / Tmat[`r',1];
    };
  };
forvalues r = 1/5 {;  /* Fill diagonal entries */
    mat TotElast[`r',`r'] = TotElast[`r',`r'] / Tmat[`r',1] - 1;
  };
matname TotElast `shnames', rows(1..5) explicit;
matname TotElast `shnames', columns(1..5) explicit;
mat list TotElast;
disp;

* Calculate cross-price elasticities matrix at extensive margin;
mat ExtElast = xmrmat + Tsqmat;
forvalues r = 2/5 {; /* Fill lower-echelon entries */
local maxcol = `r'-1;
  forvalues m = 1/`maxcol' {;
    mat ExtElast[`r',`m'] = ExtElast[`r',`m'] / Tmat[`r',1];
    };
  };
forvalues m = 2/5 {; /* Fill upper-echelon entries */
local maxrow = `m'-1;
  forvalues r = 1/`maxrow' {;
    mat ExtElast[`r',`m'] = ExtElast[`r',`m'] / Tmat[`r',1];
    };
  };
forvalues r = 1/5 {;  /* Fill diagonal entries and cancel HOM row */
    mat ExtElast[`r',`r'] = ExtElast[`r',`r'] / Tmat[`r',1] - 1;
    mat ExtElast[1,`r'] = 0;
  };
matname ExtElast `shnames', rows(1..5) explicit;
matname ExtElast `shnames', columns(1..5) explicit;
mat list ExtElast;
disp;

* Calculate cross-price elasticities matrix at intensive margin;
mat IntElast = coefmat + Tsqmat;
forvalues r = 2/5 {; /* Fill lower-echelon entries */
local maxcol = `r'-1;
  forvalues m = 1/`maxcol' {;
    mat IntElast[`r',`m'] = IntElast[`r',`m'] / Tmat[`r',1];
    };
  };
forvalues m = 2/5 {; /* Fill upper-echelon entries */
local maxrow = `m'-1;
  forvalues r = 1/`maxrow' {;
    mat IntElast[`r',`m'] = IntElast[`r',`m'] / Tmat[`r',1];
    };
  };
forvalues r = 1/5 {;  /* Fill diagonal entries */
    mat IntElast[`r',`r'] = IntElast[`r',`r'] / Tmat[`r',1] - 1;
  };
matname IntElast `shnames', rows(1..5) explicit;
matname IntElast `shnames', columns(1..5) explicit;
mat list IntElast;
disp;


/* additional concavity checks */
/*-----------------------------*/

* matrix to check (ii) that the cross price elasticities in TotElast sum to zero per row (not per column);
mat elastsum`usemissg' = J(2,5,0);
matname elastsum`usemissg' rowsum colsum, rows(1..2) explicit;
matname elastsum`usemissg' sHO sCE sDE sOI sWE, columns(1..5) explicit;
local i = 0;
foreach sreg in sHO sCE sDE sOI sWE {;
  local i = `i' + 1;
  forvalues j = 1/5 {;
    mat elastsum`usemissg'[1,`i'] = elastsum`usemissg'[1,`i'] + TotElast[`i',`j'];
    mat elastsum`usemissg'[2,`i'] = elastsum`usemissg'[2,`i'] + TotElast[`j',`i'];
    };
  };

* matrix to check (iii) that the AUmat matrices of Allen-Uzawa substitution elasticities are negative semi-definite at each observation;
* calculate MNE-level elasticities (in-sample predictions); 
* set elasticities to zero for regions with no FDI-presence;
local i = 0;
foreach reg1 in HO CE DE OI WE {;
  local i = `i' + 1;
  local j = 0;
  foreach reg2 in HO CE DE OI WE {;
    local j = `j' + 1;
    local coeff = coefmat[`i',`j'];
    if `i' ~= `j' {; 
      qui gen double sigma`reg1's`reg2' = (`coeff' + s`reg1' * s`reg2') / (s`reg1' * s`reg2') if e(sample);
      };
    if `i' == `j' {; 
      qui gen double sigma`reg1's`reg1' = (`coeff' + (s`reg1')^2 - s`reg1') / (s`reg1')^2 if e(sample);
      };      
    qui replace sigma`reg1's`reg2'=0 if sigma`reg1's`reg2'==.;
    label var sigma`reg1's`reg2' "AU elast. empl`reg1' empl`reg2'";
    };
  };
qui count;
local obsnum = `r(N)';
tempname AUmatobs eigenvec eigenval;
mat negeivalcnt`usemissg' = J(1,5,0) \ J(1,5,`obsnum');
matname negeivalcnt`usemissg' r(N_wklyneg_eigval) r(N), rows(1..2) explicit;
matname negeivalcnt`usemissg' wklyneg_1 wklyneg_2 wklyneg_3 wklyneg_4 wklyneg_5, columns(1..5) explicit;
forvalues obs = 1/`obsnum'{;
  mat `AUmatobs' = J(5,5,.);
  local i = 0;
  foreach reg1 in HO CE DE OI WE {;
    local i = `i' + 1;
    local j = 0;
    foreach reg2 in HO CE DE OI WE {;
      local j = `j' + 1;
      mat `AUmatobs'[`i',`j'] = sigma`reg1's`reg2'[`obs'];
      };
    };
  matrix symeigen `eigenvec' `eigenval' = `AUmatobs';
  matname `eigenval' `eigenval'ue, rows(1) explicit;
  mat drop `eigenvec';
  local cntwklyneg = 0;
  forvalues k = 1/5 {;
    if `eigenval'[1,`k'] <= 1.0e-06 {;  /* machine-size weakly negative */
      local cntwklyneg = `cntwklyneg' + 1;
      };
    };
  mat negeivalcnt`usemissg'[1,`cntwklyneg'] = negeivalcnt`usemissg'[1,`cntwklyneg']+1;
  };


/* matrix output */
/*---------------*/

foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  foreach type in b se e {;
    drop _all;
    matsave dprobit`r2dg'_`type', p(estmat/v3spfs/pt$par-af$aff-$waglvl-cf/byreg) t(double) replace;
    };
  drop _all;
  };

foreach type in b se e {;
    drop _all;
    matsave translog`usemissg'_`type', p(estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg') t(double) replace;
    };
matsave negxhatcnt`usemissg', p(estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace; 
matsave elastsum`usemissg', p(estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace; 
matsave negeivalcnt`usemissg', p(estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace; 

mat intelast`usemissg'_b = IntElast;
matsave intelast`usemissg'_b, p(estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;
mat extelast`usemissg'_b = ExtElast;
matsave extelast`usemissg'_b, p(estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;
mat totelast`usemissg'_b = TotElast;
matsave totelast`usemissg'_b, p(estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;

mat vce`usemissg'_tbl = `VCE';
local cols = colsof(vce`usemissg'_tbl);
matsave vce`usemissg'_tbl, p(estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;

mat tmat`usemissg'_tbl = Tmat_all;
matsave tmat`usemissg'_tbl, p(estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;
mat zetamat`usemissg'_tbl = zetamat;
matsave zetamat`usemissg'_tbl, p(estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;

mat coefmat`usemissg'_tbl = coefmat;
matname coefmat`usemissg'_tbl wHO wCE wDE wOI wWE, columns(1..5) explicit;
matname coefmat`usemissg'_tbl sHO sCE sDE sOI sWE, rows(1..5) explicit;
matsave coefmat`usemissg'_tbl, p(estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;

mat semat`usemissg'_tbl = semat;
matname semat`usemissg'_tbl wHO wCE wDE wOI wWE, columns(1..5) explicit;
matname semat`usemissg'_tbl sHO sCE sDE sOI sWE, rows(1..5) explicit;
matsave semat`usemissg'_tbl, p(estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;

mat xmrmat`usemissg'_tbl = xmrmat;
matname xmrmat`usemissg'_tbl wHO wCE wDE wOI wWE, columns(1..5) explicit;
matname xmrmat`usemissg'_tbl sHO sCE sDE sOI sWE, rows(1..5) explicit;
matsave xmrmat`usemissg'_tbl, p(estmat/v3spfs/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;

* clean up;
drop _all;
mat drop coefmat semat xmrmat zetamat Tmat Tmat_sd Tmat_N Tmat_all Tsqmat TotElast ExtElast IntElast;
foreach mat in summ_translog`usemissg' summ_translog`usemissg'_missg corrT_translog`usemissg' vce`usemissg' coefmat`usemissg' semat`usemissg' tmat`usemissg' xmrmat`usemissg' zetamat`usemissg' {;
  mat drop `mat'_tbl;
  };
foreach type in b se e r {;
  capture mat drop translog`usemissg'_`type';
  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    capture mat drop dprobit`r2dg'_`type';
    capture mat drop sure2stp`r2dg'_`type';
    };
  };
mat drop negxhatcnt`usemissg' elastsum`usemissg' negeivalcnt`usemissg';
mat drop totelast`usemissg'_b;
mat drop intelast`usemissg'_b;
mat drop extelast`usemissg'_b;
mat drop pscdlnw suredps;

}; /* end of `usemissg' loop */

*----------------------above code identical to translog-selct-2stp-cf-semiparam.do-------------------------------------------;

log close;
cd "$root";
