*! version 1.0.1  26may2005  by Marc Muendler muendler@ucsd.edu

clear
set memory 400m
set matsize 400
set more off
capture log close

cd "$rootslct"

log using "logs/reg-pattern-pt$par-af$aff-ger.log", replace

capture mkdir "$rootslct/tex/desc"
capture mkdir "$rootslct/tex/desc/pt$par-af$aff"

mat drop _all

adopath + "$root/%stata/ado"

#delimit ;


/* data */
/*------*/

foreach year in 1996 2000 {;

tempfile dat`year';
use "$rootslct/Xdata/mneid-outwfdi-ustan-`year'-translog-frmowwwage-pt$par-af$aff", clear;
drop cf;

replace cntrybemgrp=(substr(cntrybemgrp,1,2));

* construct stacked system;
foreach var in s w t k l {;
    replace `var'=0 if `var'==.;
    };
reshape wide s w t k l naff nofdi, i(mneid nreg) j(cntrybemgrp) string;

merge mneid using "$rootslct/Xdata/mvprobit-outwfdi-ustan-2000-pt$par-af$aff";
tab _merge;
drop _merge;
sort mneid;

* competitor regressors;
merge mneid using "$rootslct/Xdata/mneid-outwfdi-ustan-1996-costothr-frmowwwage-pt$par-af$aff";
tab _merge;
foreach var in s k t l w wb {;
  foreach reg in $regagg {;
    qui gen _avg_`var'_`reg' = `var'_othr_`reg' if _m==2; /* market average (mneid==0 in using data) */
    qui egen _rpl_`var'_`reg' = max(_avg_`var'_`reg');
    qui replace `var'_othr_`reg' = _rpl_`var'_`reg' if `var'_othr_`reg'==.; /* replace missing competitor info with market average (mneid==0 in using data) */
    drop _avg_`var'_`reg' _rpl_`var'_`reg';
    };
  };
drop if mneid==0;
drop _merge;
sort mneid;
merge mneid using "$rootslct/Xdata/mneid-outwfdi-ustan-1996-wwlocvars-pt$par-af$aff";
foreach var in employmt ln_dist ln_gdp ln_gdp_cap ln_consum_exp ln_cons_cap lh99_1 lh99_2 {;
  qui gen _avg_`var' = `var'_othr if _m==2; /* market average (mneid==0 in using data) */
  qui egen _rpl_`var' = max(_avg_`var');
  qui replace `var'_othr = _rpl_`var' if `var'_othr==.; /* replace missing competitor info with market average (mneid==0 in using data) */
  drop _avg_`var' _rpl_`var';
  };
drop if mneid==0;
tab _merge;
drop _merge;
sort mneid;

* regional presence indicators and parent level regressors;
foreach reg in $regagg {;
  foreach 4dyr in 1996 2000 {;
    local yr = substr("`4dyr'",-2,2);
    local r2dg = substr("`reg'",1,2);
    rename chosen_`reg'_`4dyr' i`r2dg'`yr';
    rename ln_wagediff_`reg'_`4dyr' ln_wdiff_`r2dg'`yr';
    };
  };
foreach 4dyr in 1996 2000 {;
  local yr = substr("`4dyr'",-2,2);
  rename ln_inter_`4dyr' ln_inter`yr';
  foreach var in ln_employmt ln_exports ln_fixdasst ln_assettot ln_profits ln_turnover ln_equity ln_liab ln_caplabrat profeqtyrat {;
    rename `var'_par_`4dyr' `var'`yr';
    };
  };
gen byte iHO96 = 1;  /* Permanent presence in Home */
gen byte iHO00 = 1;  /* Permanent presence in Home */
drop w_HOM_2000; rename w_HOM_1996 w_HOM;  /* Use 1998 BA wages (1996 proxied with 1998) */

gen int year = `year';
drop w*;  /* drop all wage information (otherwise use of -frmowwwage matters) */

save `dat`year'';

};

use `dat1996';
append using `dat2000';
duplicates drop;
sort mneid year;
order mneid year nreg i*;


/* parent and affiliate counts */
/*-----------------------------*/

preserve;
rename mneid firmid_wenger;
sort firmid_wenger year;
merge firmid_wenger year using "$rootslct/Xdata/affils-fdi-ustan-96&00-plaineur", nokeep;
tab _m;
rename firmid_wenger mneid;
keep mneid affil2id year;
codebook mneid affil2id year;
restore;


/* check overlap of pattern variables */
/*------------------------------------*/

egen byte _nregprbt96 = rsum(iCE96 iDE96 iOI96 iWE96 iHO96) if year==1996;
egen byte _nregprbt00 = rsum(iCE00 iDE00 iOI00 iWE00 iHO00) if year==2000;
egen byte nregprbt = rsum(_nregprbt96 _nregprbt00);
drop _nregprbt96 _nregprbt00;
bysort year: summ nregprbt nreg;
* note: there are differences between translog and probit presence patterns;
*       translog may differ from probit presence information due to missing variables;


/* pattern statistics */
/*--------------------*/

tsset mneid year;

* transitions based on probit presence information (nregprbt);
gen byte _ind = (nregprbt==.);
replace nregprbt = 0 if _ind; /* to check for missing in transition table */
xttrans nregprbt, freq;
replace nregprbt = . if _ind;
drop _ind;

* transitions based on probit presence information (nregprbt), ignoring home presence;
gen byte _ind = (nregprbt==1);
replace nregprbt = . if _ind; /* to check for missing in transition table */
xttrans nregprbt, freq;
replace nregprbt = 1 if _ind;
drop _ind;
tab nregprbt if year==1996;
tab nregprbt if year==2000;

* transitions based on translog presence information (nreg);
gen byte _ind = (nreg==.);
replace nreg = 0 if _ind; /* to check for missing in transition table */
xttrans nreg, freq;
replace nreg = . if _ind;
drop _ind;

* transitions based on translog presence information (nreg), ignoring missing;
xttrans nreg, freq;
tab nreg if year==1996;
tab nreg if year==2000;

* change in affiliate numbers;
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  gen del_naff`r2dg' = naff`r2dg' - l.l.l.l.naff`r2dg';
  };
summ2tex naff* del_naff*, c(mean sd N p50) name(summ_del_naff) p(tex/desc/pt$par-af$aff) replace detail;
summ2tex naff* del_naff* if year==1996, c(mean sd N p50) name(summ_del_naff96) p(tex/desc/pt$par-af$aff) replace detail;
summ2tex naff* del_naff* if year==2000, c(mean sd N p50) name(summ_del_naff00) p(tex/desc/pt$par-af$aff) replace detail;
mat drop summ_del_naff_tbl summ_del_naff96_tbl summ_del_naff00_tbl;

preserve;
drop if year==1996;
keep mneid del_naff*;
reshape long del_naff, i(mneid) j(cntrybemgrp) string;
drop if del_naff==.;
* gen str str_del_naff = string(del_naff);
* replace str_del_naff = ">5" if del_naff > 5;
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  replace cntrybemgrp = "`reg'" if cntrybemgrp=="`r2dg'";
  };
encode cntrybemgrp, gen(cntrygrp) label(cntrygrp);
* table del_naff cntrygrp, c(count mneid);
tabl2tex mneid, type(count) r(del_naff) c(cntrygrp) p(tex/desc/pt$par-af$aff) name(delnaff) fancy replace;
mat drop delnaff_tbl;
restore, preserve;

foreach year in 1996 2000 {;
restore, preserve;
local yr = substr("`year'",-2,2);
keep if year==`year';
gen str pattern = "";
foreach reg in HOM $regagg {;
  local r2dg = substr("`reg'",1,2);
  replace pattern = pattern + " `reg'" if i`r2dg'`yr'==1;
  replace pattern = pattern + "    " if i`r2dg'`yr'==0;
  };
replace pattern = trim(pattern);
tab pattern;
gen byte _ones = 1;
encode pattern, generate(_pattern) label(pattern);
* table pattern, c(count mneid);
tabl2tex mneid, type(count) r(_pattern) c(_ones) p(tex/desc/pt$par-af$aff) name(pattern`yr') fancy replace;
mat drop pattern`yr'_tbl;
};
restore;


/* additional pattern statistics */
/*-------------------------------*/

use "Xdata/data-parent-hostcntry-pt$par-af$aff", clear;
keep firmid country year;
rename firmid mneid;
by mneid: egen cntrycnt = count(country);
drop country;
duplicates drop;
* table cntrycnt year, c(count mneid);
preserve;
tabl2tex mneid, type(count) r(cntrycnt) c(year) p(tex/desc/pt$par-af$aff) name(countries_compl) fancy replace;
restore;
gen str _cntrycnt = string(cntrycnt);
replace _cntrycnt = ">9" if cntrycnt>9;
encode _cntrycnt, gen(trunccntrycnt) label(cntrycnt);
drop _cntrycnt;
tabl2tex mneid, type(count) r(trunccntrycnt) c(year) p(tex/desc/pt$par-af$aff) name(countries) fancy replace;


log close;
cd "$root";
