*! version 1.0.4  15jan2006  by Marc Muendler muendler@ucsd.edu

cd "$rootslct"
clear
set mem 400m
set more off

capture mkdir "$rootslct/tex/desc"
capture mkdir "$rootslct/tex/desc/pt$par-af$aff"  /* Directories unaffected if they exist */

capture log close
log using "logs/regagg-pt$par-af$aff-ger.log", replace

/* Create comparable aggregate data to FDI select samples */
* Note: file "tex/desc/pt$par-af$aff/employment-population-`year'" reports employment at Direk MNEs
*       file "tex/desc/pt$par-af$aff/employment-transf-population-`year'" reports employment at MNEs found in Ustan

/* External files */

tempfile isocntry naceconc
tempfile secfix
global secfix "`secfix'"

use "$root/conc/sector-conc-nace", clear
sort buba_code
save `naceconc'

use "$root/conc/fdi-iso-country", clear
sort buba
compress
save `isocntry'

tempfile iso3buba
use "$root/conc/fdi-iso-country", clear
rename buba country
keep iso3code country 
sort country
compress
save `iso3buba'

tempfile cntrgrpbem
use "$root/conc/cntry2bemgrp", clear
rename bubakey country
sort country
compress
save `cntrgrpbem'

do "$dpref/#sector-definitions.do"


/* Plain EUR Data */

use "$rootslct/Xdata/affils-fdiall-ustan-00-plaineur.dta", clear
label var standalone "Indic.: No domestic match"
keep firmid affil2id year country share standalone consol_par sec1 sec2_fix employmt* turnover* assettot* fixdasst* equity* liab_par profits_par exports_par wb* ustan
order firmid affil2id year country share standalone consol_par sec1 sec2_fix employmt* turnover* assettot* fixdasst* equity* liab_par profits_par exports_par wb* ustan
sort firmid affil2id year

keep if share>.5  /* Keep majority-owned affiliates only */

* country_grp definitions (as in swe-ger-conc.do)
foreach var in country {
    * tab `var'
    rename `var' bubakey  
    sort bubakey 
    merge bubakey using "$root/conc/cntry2bemgrp", nokeep
    count if _m~=3 & bubakey~=.
    if `r(N)' > 0 {
        disp as err "Incomplete country concordance"
        STOP
        }
    rename bubakey `var'
    rename cntrygrp_bem `var'grp_fix
    drop _merge
    }
rename countrygrp_fix cntrygrp_bem
label var cntrygrp_bem "Country group of affiliate"
sort firmid affil2id year

* sector and country resetting (similar to prep-summarize-affils.do)
do "$dpref/#sector-country-resetting.do"

keep firmid affil2id year country share cntrybemgrp standalone consol_par sec1_bem sec1_aggbem sec2_bem sec2_aggbem employmt* turnover* assettot* fixdasst* equity* liab_par profits_par exports_par wb* ustan
order firmid affil2id year country share cntrybemgrp standalone consol_par sec1_bem sec1_aggbem sec2_bem sec2_aggbem employmt* turnover* assettot* fixdasst* equity* liab_par profits_par exports_par wb* ustan

if "$par" == "manf" {
  keep if sec1_aggbem>=2 & sec1_aggbem<=4
  }
if "$par" == "nonmf" {
  drop if sec1_aggbem>=2 & sec1_aggbem<=4
  }
if "$aff" == "manf" {
  keep if sec2_aggbem>=2 & sec2_aggbem<=4
  }
if "$aff" == "nonmf" {
  drop if sec2_aggbem>=2 & sec2_aggbem<=4
  }
* "$aff" == "all": nothing to drop


/* Population totals for FDI firms */
preserve
local year 2000
* forvalues year = 1996/2001 {
  keep if year==`year'
  collapse (sum) tot_empl=employmt (mean) avg_empl=employmt, by(cntrybemgrp) fast
  label var cntrybemgrp "Country group BEM"
  label var tot_empl "Total employment"
  label var avg_empl "Mean employment"
  order cntrybemgrp tot_empl avg_empl
  sort cntrybemgrp
  compress
  save "$rootslct/tex/desc/pt$par-af$aff/employment-population-`year'", replace
restore, preserve
  keep if year==`year'
  keep firm employmt_par
  duplicates drop
  collapse (sum) tot_empl=employmt_par (mean) avg_empl=employmt_par, fast
  label var tot_empl "Total employment"
  label var avg_empl "Mean employment"
  order tot_empl avg_empl
  local mnes = tot_empl[1]/avg_empl[1]
  append using "$rootslct/tex/desc/pt$par-af$aff/employment-population-`year'"
  replace cntrybemgrp = 0 if cntrybemgrp==.
  label define cntrybem 0 "HOM", modify
  order cntrybemgrp tot_empl avg_empl
  rename avg_empl avg_empl_aff
  label var avg_empl_aff "Mean employment by affiliate"
  gen avg_empl_par = tot_empl/`mnes'
  label var avg_empl_par "Mean employment by parent"
  sort cntrybemgrp
  compress
  save "$rootslct/tex/desc/pt$par-af$aff/employment-population-`year'", replace
restore, preserve
* }
restore


/* Host country aggregation */

#delimit ;
sort firmid country year;
local i = 0;
foreach var of varlist 
            employmt wb_ppp
            turnover turnover_ppp 
            fixdasst fixdasst_ppp 
            assettot assettot_ppp 
            equity equity_ppp 
            employmt_par wb_par
            turnover_par fixdasst_par assettot_par 
            equity_par liab_par profits_par exports_par 
            ustan sec1_bem sec1_aggbem standalone consol_par {;
  local i = `i' + 1;
  local lbl`i' : variable label `var';
  };
collapse (sum) employmt wb_ppp
               turnover turnover_ppp 
               fixdasst fixdasst_ppp 
               assettot assettot_ppp 
               equity equity_ppp 
       (count) number_invest=affil2id 
         (max) employmt_par wb_par
               turnover_par fixdasst_par assettot_par 
               equity_par liab_par profits_par exports_par 
               ustan sec1_bem sec1_aggbem standalone consol_par,
           by (firmid country year) fast;
local i = 0;
foreach var of varlist 
            employmt wb_ppp
            turnover turnover_ppp 
            fixdasst fixdasst_ppp 
            assettot assettot_ppp 
            equity equity_ppp 
            employmt_par wb_par
            turnover_par fixdasst_par assettot_par 
            equity_par liab_par profits_par exports_par 
            ustan sec1_bem sec1_aggbem standalone consol_par {;
  local i = `i' + 1;
  label variable `var' "`lbl`i''";
  };
label var number_invest "Count of Affiliates";
foreach var of varlist fixdasst_ppp equity_ppp turnover_ppp employmt assettot_ppp {;
  replace `var'=. if `var'==0;
  };
compress;
#delimit cr                     

order firmid ustan sec1_bem country year
drop if ustan==.  /* Drop the FDI_all part, no lags needed in estimation */
sort country
merge country using `iso3buba', nokeep
tab _m
drop _m
sort country
merge country using `cntrgrpbem', nokeep
tab _m
keep firmid ustan year iso3code country cntrygrp_bem standalone consol_par sec1_bem sec1_aggbem year turnover_par turnover_ppp employmt_par employmt wb_par wb_ppp fixdasst_par fixdasst_ppp
order firmid ustan year iso3code country cntrygrp_bem standalone consol_par sec1_bem sec1_aggbem year turnover_par turnover_ppp employmt_par employmt wb_par wb_ppp fixdasst_par fixdasst_ppp


* Apply BEM cntrybemgrp definitions
/*-----------------------
 WEU: EMU (3), OWE (6);
 OIN: OIN (5);
 CEE: CEE (2); 
 DEV: APC (1), ODV (4) and RCA (7)
 --------------------------------------------*/
tab cntrygrp_bem
order firmid ustan country cntrygrp_bem
gen str3 cntrybemgrp = "CEE" if cntrygrp_bem=="CEE"
replace  cntrybemgrp = "DEV" if cntrygrp_bem=="APC" | cntrygrp_bem=="ODV" | cntrygrp_bem=="OTR" | cntrygrp_bem=="RCA"
replace  cntrybemgrp = "OIN" if cntrygrp_bem=="OIN"
replace  cntrybemgrp = "WEU" if cntrygrp_bem=="EMU" | cntrygrp_bem=="OWE"
label var cntrybemgrp "Country group BEM"
rename cntrybemgrp _cntrybemgrp
encode _cntrybemgrp, gen(cntrybemgrp) label(cntrybem)
drop _cntrybemgrp

keep firmid ustan year country cntrybemgrp iso3code sec1_bem sec1_aggbem fixdasst_par turnover_par employmt_par fixdasst_ppp turnover_ppp employmt wb_par wb_ppp
order firmid ustan year country cntrybemgrp iso3code sec1_bem sec1_aggbem fixdasst_par turnover_par employmt_par fixdasst_ppp turnover_ppp employmt wb_par wb_ppp
sort firmid country year

/* Data adjustment */
* Transform data to MNE level
* A dataset with R+1 lines per firm results, where R is the number of foreign in which the MNE operates and "1" stands for Home
rename firmid firm
tempfile hom
preserve
     keep if employmt_par~=.
     keep firm year sec1_aggbem employmt_par fixdasst_par turnover_par wb_par
     gen byte cntrybemgrp = 0
     foreach var in employmt fixdasst turnover wb { 
       rename `var'_par `var'
       }
     duplicates drop
     compress
     sort firm
     save `hom'
 restore
     keep firm year sec1_aggbem cntrybemgrp country employmt fixdasst_ppp turnover_ppp wb_ppp
     foreach var in fixdasst turnover wb {
       rename `var'_ppp `var'
       }
     duplicates drop
     compress
     sort firm
append using `hom'
label define cntrybem 0 "HOM", modify


/* Save employment pattern in sample */

preserve
local year 2000
* forvalues year = 1996/2001 {
  keep if year==`year'
  keep firm employmt cntrybemgrp
  collapse (sum) employmt, by(firm cntrybemgrp) fast
  reshape wide employmt, i(firm) j(cntrybemgrp)
  forvalues reg = 1/4 {
    replace employmt`reg' = 0 if employmt`reg'==.
    }
  reg employmt0 employmt1-employmt4
  tempname predb`year'
  mat `predb`year'' = get(_b)
restore, preserve
  keep if year==`year'
  collapse (sum) tot_empl_tf=employmt (mean) avg_empl_par_tf=employmt, by(cntrybemgrp) fast
  label var cntrybemgrp "Country group BEM"
  label var tot_empl "Total employment"
  label var avg_empl_par "Mean employment by parent"
  order cntrybemgrp tot_empl avg_empl
  sort cntrybemgrp
  compress
  merge cntrybemgrp using "$rootslct/tex/desc/pt$par-af$aff/employment-population-`year'"
  drop _m
  mkmat tot_empl_tf, matrix(empl_tf)
  mat empl_tf = empl_tf[2..5,1] \ J(1,1,1)
  mkmat tot_empl, matrix(empl_pred)
  mat empl_pred = empl_pred[2..5,1] \ J(1,1,1)
  mat pop_empl_tf = `predb`year'' * empl_tf
  mat pop_empl = `predb`year'' * empl_pred
  sort cntrybemgrp
  rename tot_empl pop_empl
  replace pop_empl = pop_empl[1,1] if cntrybemgrp==0
  save "$rootslct/tex/desc/pt$par-af$aff/employment-transf-population-`year'", replace
restore, preserve
* }
restore

mat drop pop_empl pop_empl_tf empl_pred empl_tf

log close
cd "$root"
